==> apache-calcite-1.15.0-src.tar.gz: apache-calcite-1.15.0-src/core/src/main/java/org/apache/calcite/materialize/DelegatingLatticeStatisticProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.materialize;

import java.util.List;

/**
 * Implementation of {@link LatticeStatisticProvider} that delegates
 * to an underlying provider.
 */
public class DelegatingLatticeStatisticProvider
    implements LatticeStatisticProvider {
  protected final LatticeStatisticProvider provider;

  /** Creates a DelegatingLatticeStatisticProvider.
   *
   * @param provider Provider to which to delegate otherwise unhandled requests
   */
  protected DelegatingLatticeStatisticProvider(
      LatticeStatisticProvider provider) {
    this.provider = provider;
  }

  public double cardinality(List<Lattice.Column> columns) {
    return provider.cardinality(columns);
  }
}

// End DelegatingLatticeStatisticProvider.java

==> apache-calcite-1.40.0-src.tar.gz: apache-calcite-1.40.0-src/core/src/main/java/org/apache/calcite/materialize/DelegatingLatticeStatisticProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.materialize;

import java.util.List;

/**
 * Implementation of {@link LatticeStatisticProvider} that delegates
 * to an underlying provider.
 */
public class DelegatingLatticeStatisticProvider
    implements LatticeStatisticProvider {
  protected final LatticeStatisticProvider provider;

  /** Creates a DelegatingLatticeStatisticProvider.
   *
   * @param provider Provider to which to delegate otherwise unhandled requests
   */
  protected DelegatingLatticeStatisticProvider(
      LatticeStatisticProvider provider) {
    this.provider = provider;
  }

  @Override public double cardinality(List<Lattice.Column> columns) {
    return provider.cardinality(columns);
  }
}
